
// GUIPanel.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, November 2004

/* This JPanel contains the GUI components for application. 

   For this example, the user can click on a button to open a JFileChooser 
   to select an image to display in a scrolling pane.

   This JPanel has no layout manager since the GUI components have to
   be positoned based on the location of features in the background
   image.

   ---------
   Same as in ShapelyImagePane example, except for (x,y) coords
   of the FileChooser and the button.
*/ 


import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import javax.swing.filechooser.*;


public class GUIPanel extends JPanel implements ActionListener
{
  private final static String IMAGE_DIR = "images/";

  // GUI elements
  private JFileChooser fc;
  private JLabel displayLabel;


  public GUIPanel(int bgImWidth, int bgImHeight)
  {
    setLayout(null);                  // no layout manager
    setSize(bgImWidth, bgImHeight);   // same size as background image
    setOpaque(false);                 // the panel is invisible

    // setBorder(BorderFactory.createLineBorder(Color.white));
         // shows a white border which can be useful during debugging

    // create file chooser
    fc = new JFileChooser();
    fc.setFileFilter( new PicsFilter() );
    fc.setCurrentDirectory( new File(IMAGE_DIR) );

    // create open-file button 
    JButton openButton = new JButton("Open File", new ImageIcon("openIcon.gif"));
    openButton.addActionListener(this);
    openButton.setBounds(40, 180, 115, 24);   // determined by trial-and-error
    // openButton.setBounds(321, 88, 115, 24);

    // label for showing loaded image
    displayLabel = new JLabel("Image appears here", JLabel.CENTER);

	// place inside a scrollPane
	JScrollPane jsp = new JScrollPane( displayLabel );
	jsp.setPreferredSize( new Dimension(144, 144) );
    jsp.setBounds(20, 20, 144, 144);    // determined by trial-and-error
    // jsp.setBounds(80, 84, 144, 144); 

    add(openButton);
	add(jsp);
  }  // end of GUIPanel()


  public void actionPerformed(ActionEvent e)
  // load image from file
  {  
    int returnVal = fc.showOpenDialog(this);
    if (returnVal == JFileChooser.APPROVE_OPTION) {
      File file = fc.getSelectedFile();
      ImageIcon im = new ImageIcon( file.getPath());
      displayLabel.setText("");
	  displayLabel.setIcon( im );
    }
  } // end of actionPerformed()

} // end of GUIPanel class


// =============================================

class PicsFilter extends javax.swing.filechooser.FileFilter 
// Filter the files for image extensions, and allow sub-directories
{
  public boolean accept(File file) 
  {
    String fnm = file.getName().toLowerCase();
    if ( fnm.endsWith(".jpg") || fnm.endsWith(".jpeg") ||
         fnm.endsWith(".gif") || file.isDirectory() )
      return true;
    else
      return false;
  } // end of accept()

  public String getDescription() 
  { return "JPG and GIF Images"; }

} // end of PicsFilter class

